@@ -7,18 +7,17 @@ class DictionaryInfo(object):
     A list of dictionaries used by MeCab is returned by the dicts attribute of
     MeCab. Each dictionary information includes the attributes listed below.
 
-    Attributes:
-        ptr: This dictionary's pointer.
-        filename: Full path to the dictionary file.
-        charset: Dictionary character set, e.g., "SHIFT-JIS", "UTF-8".
-        size: Number of words registered in this dictionary.
-        type: Dictionary type; 0 (SYS_DIC), 1 (USR_DIC), 2 (UNK_DIC)
-        lsize: Left attributes size.
-        rsize: Right attributes size.
-        version: Dictionary version.
-        next: Pointer to next dictionary information struct.
+    :ivar ptr: FFI pointer to the mecab_dictionary_info_t.
+    :ivar filepath: Full path to the dictionary file.
+    :ivar charset: Dictionary character set, e.g., SHIFT-JIS, UTF-8.
+    :ivar size: Number of words registered in this dictionary.
+    :ivar type: Dictionary type; 0 (SYS_DIC), 1 (USR_DIC), 2 (UNK_DIC)
+    :ivar lsize: Left attributes size.
+    :ivar rsize: Right attributes size.
+    :ivar version: Dictionary version.
+    :ivar next: Pointer to next dictionary information struct.
 
-    Example usage:
+    Example usage::
 
         from natto import MeCab
 
@@ -26,13 +25,13 @@ class DictionaryInfo(object):
             # first dictionary info is MeCab's system dictionary
             sysdic = nm.dicts[0]
 
-            print(sysdic.filename)
+            print(sysdic.filepath)
 
             print(sysdic.charset)
 
             print(sysdic.is_sysdic())
     '''
-    _REPR_FMT = '<{}.{} pointer={}, type={}, filename="{}", charset="{}">'
+    _REPR_FMT = '<{}.{} pointer={}, filepath="{}", charset={}, type={}>'
 
     # System dictionary
     SYS_DIC = 0
@@ -41,10 +40,9 @@ class DictionaryInfo(object):
     # Unknown dictionary.
     UNK_DIC = 2
 
-    def __init__(self, dptr, filename, charset):
-        '''Initializes the MeCab dictionary information.'''
+    def __init__(self, dptr, filepath, charset):
         self.ptr = dptr
-        self.filename = filename
+        self.filepath = filepath
         self.charset = charset
         self.size = dptr.size
         self.type = dptr.type
@@ -54,29 +52,41 @@ class DictionaryInfo(object):
         self.next = getattr(dptr, 'next')
 
     def is_sysdic(self):
-        '''Returns True if this is a system dictionary.'''
+        '''Is this a system dictionary?
+
+        :return: True if system dictionary, False otherwise.
+        '''
         return self.type == self.SYS_DIC
 
     def is_usrdic(self):
-        '''Returns True if this is a user-defined dictionary.'''
+        '''Is this a user-defined dictionary?
+
+        :return: True if user-defined dictionary, False otherwise.
+        '''
         return self.type == self.USR_DIC
 
     def is_unkdic(self):
-        '''Returns True if this is a unknown dictionary.'''
+        '''Is this an unknown dictionary?
+
+        :return: True if unknown dictionary, False otherwise.
+        '''
         return self.type == self.UNK_DIC
 
     def __repr__(self):
-        '''Returns a string representation of this MeCab dictionary.'''
+        '''Return a string representation of this MeCab dictionary.
+
+        :return: str - string representation.
+        '''
         return self._REPR_FMT.format(type(self).__module__,
                                      type(self).__name__,
                                      self.ptr,
-                                     self.type,
-                                     self.filename,
-                                     self.charset)
+                                     self.filepath,
+                                     self.charset,
+                                     self.type)
 
 
 '''
-Copyright (c) 2014, Brooke M. Fujita.
+Copyright (c) 2014-2015, Brooke M. Fujita.
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
