@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 '''The main interface to MeCab via natto-py.'''
 import argparse
+import os
 import sys
 from .api import MeCabError
 from .binding import _ffi_libmecab
@@ -16,17 +17,20 @@ class MeCab(object):
     surface and related features, or for parsing as MeCab nodes which contain
     detailed information about the morphemes encompassed.
 
-    Example usage:
+    Example usage::
 
         from natto import MeCab
 
         with MeCab() as nm:
             # output MeCab version
             print(nm.version)
+            
+            # output absolute path to MeCab library
+            print(nm.libpath)
 
-            # output filename and charset for the MeCab system dictionary
+            # output file path and charset for the MeCab system dictionary
             sysdic = nm.dicts[0]
-            print(sysdic.filename)
+            print(sysdic.filepath)
             print(sysdic.charset)
 
             # parse a string
@@ -36,7 +40,7 @@ class MeCab(object):
             # and display much more detailed information about each morpheme
             for n in nm.parse('飛べねえ鳥もいるってこった。', as_nodes=True):
                 if n.is_nor():
-                    print("{}\t{}\t{}".format(n.surface, n.posid, n.wcost))
+                    print("{}\\t{}\\t{}".format(n.surface, n.posid, n.wcost))
     '''
     MECAB_PATH = 'MECAB_PATH'
     MECAB_CHARSET = 'MECAB_CHARSET'
@@ -47,8 +51,8 @@ class MeCab(object):
     _ERROR_NULLPTR = 'Could not initialize MeCab'
     _ERROR_NVALUE = 'Invalid N value'
 
-    _REPR_FMT = ('<{}.{} lib="{}", pointer={}, options={}, dicts={},'
-                 ' version="{}">')
+    _REPR_FMT = ('<{}.{} pointer={}, libpath="{}", options={}, dicts={},'
+                 ' version={}>')
 
     _FN_NBEST_TOSTR = 'mecab_nbest_sparse_tostr'
     _FN_NBEST_TONODE = 'mecab_nbest_init'
@@ -91,8 +95,7 @@ class MeCab(object):
         Lattice-level option has been deprecated; please use marginal or nbest
         instead.
 
-        Args:
-            options: string or dictionary of options to use when instantiating
+        :options string or dictionary of options to use when instantiating
                 the MeCab instance. May be in short- or long-form, or in a
                 Python dictionary.
 
@@ -249,7 +252,7 @@ class MeCab(object):
             env = MeCabEnv()
             self.__ffi = _ffi_libmecab()
             self.__mecab = self.__ffi.dlopen(env.libpath)
-            self.lib = env.libpath
+            self.libpath = env.libpath
 
             # Set up byte/Unicode converters (Python 3 support)
             def __23_support():
@@ -328,9 +331,10 @@ class MeCab(object):
         self.dicts = []
         dptr = self.__mecab.mecab_dictionary_info(self.pointer)
         while dptr != self.__ffi.NULL:
-            fname = self.__out2str(self.__ffi.string(dptr.filename))
+            fpath = self.__out2str(self.__ffi.string(dptr.filename))
+            fpath = os.path.abspath(fpath)
             chset = self.__out2str(self.__ffi.string(dptr.charset))
-            self.dicts.append(DictionaryInfo(dptr, fname, chset))
+            self.dicts.append(DictionaryInfo(dptr, fpath, chset))
             dptr = getattr(dptr, 'next')
 
         # Save value for MeCab's internal character encoding
@@ -442,27 +446,22 @@ class MeCab(object):
         '''Returns a string representation of this MeCab instance.'''
         return self._REPR_FMT.format(type(self).__module__,
                                      type(self).__name__,
-                                     self.lib,
                                      self.pointer,
+                                     self.libpath,
                                      self.options,
                                      self.dicts,
                                      self.version)
 
     def parse(self, text, as_nodes=False):
-        '''Parses the given text.
+        '''Parse the given text.
 
-        Args:
-            text: the text to parse.
-            as_nodes: flag indicating whether to parse as nodes or strings;
-                defaults to False (string parsing).
-
-       Returns:
-            A single string containing the entire MeCab output;
+        :param text: the text to parse.
+        :type text: str
+        :param as_nodes: flag indicating whether to parse as nodes or strings;
+        :type as_nodes: bool, defaults to False
+        :return: A single string containing the entire MeCab output;
             or a Generator yielding the MeCab nodes.
-
-        Raises:
-            MeCabError: a null argument was passed in;
-                        or an unforseen error occurred during the operation.
+        :raises: MeCabError
         '''
         if text is None:
             raise MeCabError(self._ERROR_EMPTY_STR)
@@ -477,7 +476,7 @@ class MeCab(object):
 
 
 '''
-Copyright (c) 2014, Brooke M. Fujita.
+Copyright (c) 2014-2015, Brooke M. Fujita.
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
