@@ -1,23 +1,23 @@
 # -*- coding: utf-8 -*-
 '''Test suite for natto-py'''
 import unittest
-#from .test_binding import TestBinding
-#from .test_dictionary import TestDictionary
+from .test_binding import TestBinding
+from .test_dictionary import TestDictionary
 from .test_environment import TestMeCabEnv
 from .test_mecab import TestMecab
 
 def test_suite():
     '''Returns suite of tests for natto-py'''
     suite = unittest.TestSuite()
-#    suite.addTest(TestBinding)
-#    suite.addTest(TestDictionary)
+    suite.addTest(TestBinding)
+    suite.addTest(TestDictionary)
     suite.addTest(TestMeCabEnv)
     suite.addTest(TestMecab)
     return suite
 
 
 '''
-Copyright (c) 2014, Brooke M. Fujita.
+Copyright (c) 2014-2015, Brooke M. Fujita.
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
